@@ -3,7 +3,7 @@ import logging
 import pprint
 
 from . import constants
-from .enums import Guid, NamedPropertyType
+from .enums import NamedPropertyType
 from .utils import bytesToGuid, divide, properHex, roundUp
 from compressed_rtf.crc32 import crc32
 
@@ -35,7 +35,7 @@ class Named:
 
         # Check that we even have any entries. If there are none, nothing to do.
         if entryStream:
-            guids = tuple([None, Guid.PS_MAPI.value, Guid.PS_PUBLIC_STRINGS.value] + [bytesToGuid(x) for x in divide(guidStream, 16)])
+            guids = tuple([None, constants.PS_MAPI, constants.PS_PUBLIC_STRINGS] + [bytesToGuid(x) for x in divide(guidStream, 16)])
             entries = []
             for rawStream in divide(entryStream, 8):
                 tmp = constants.STNP_ENT.unpack(rawStream)
@@ -45,7 +45,7 @@ class Named:
                     'guid_index': tmp[1] >> 1,
                     'pkind': NamedPropertyType(tmp[1] & 1), # 0 if numerical, 1 if string.
                     'rawStream': rawStream,
-                    }
+                }
                 entry['guid'] = guids[entry['guid_index']]
                 entries.append(entry)
 
@@ -66,7 +66,8 @@ class Named:
                 self.__properties.append(StringNamedProperty(entry, names[entry['id']]) if entry['pkind'] == NamedPropertyType.STRING_NAMED else NumericalNamedProperty(entry))
 
             for property in self.__properties:
-                self.__propertiesDict[property.name if isinstance(property, StringNamedProperty) else property.propertyID] = property
+                name = property.name if isinstance(property, StringNamedProperty) else property.propertyID
+                self.__propertiesDict[(name, property.guid)] = property
 
     def __getitem__(self, key):
         return self.__propertiesDict[key]
@@ -104,8 +105,8 @@ class Named:
 
     def get(self, propertyName, default = None):
         """
-        Tries to get a named property based on its name. Returns :param default:
-        if not found.
+        Tries to get a named property based on its key. Returns :param default:
+        if not found. Key is a tuple of the name and the property set GUID.
         """
         try:
             return self.__propertiesDict[propertyName]
@@ -123,7 +124,7 @@ class Named:
         """
         Uses the pprint function on a sorted list of keys.
         """
-        pprint.pprint(sorted(tuple(self.__propertiesDict.keys())))
+        pprint.pprint(sorted(self.__propertiesDict.keys()))
 
     def values(self):
         return self.__propertiesDict.values()
@@ -167,12 +168,20 @@ class NamedProperties:
         self.__streamSource = streamSource
 
     def __getitem__(self, item):
+        """
+        Get a named property using the [] operator. Item must be a named
+        property instance or a tuple with 2 items: the name and the GUID string.
+        """
         if isinstance(item, NamedPropertyBase):
             return self.__streamSource._getTypedData(item.propertyStreamID)
         else:
             return self.__streamSource._getTypedData(self.__named[item].propertyStreamID)
 
     def get(self, item, default = None):
+        """
+        Get a named property, returning the value of :param default: if not
+        found. Item must be a tuple with 2 items: the name and the GUID string.
+        """
         try:
             return self[item]
         except KeyError:
@@ -244,7 +253,7 @@ class StringNamedProperty(NamedPropertyBase):
         # generated by certain versions of Outlook. As such, a little bit of
         # additional code will need to run to determine exactly what the stream
         # ID should be if it is in that property set.
-        if self.guid == Guid.PS_INTERNET_HEADERS.value:
+        if self.guid == constants.PS_INTERNET_HEADERS:
             # To be sure if it needs to be lower the most effective method would
             # be to just get the Stream ID and then check if the entry is in
             # there. If it isn't, then check the regular case and see. If it is
